/*
The software in this package is distributed under the GNU General
Public License version 2 (with a special exception described below).

A copy of GNU General Public License (GPL) is included in this distribution,
in the file COPYING.GPL.

As a special exception, if other files instantiate templates or use macros
or inline functions from this file, or you compile this file and link it
with other works to produce a work based on this file, this file
does not by itself cause the resulting work to be covered
by the GNU General Public License.

However the source code for this file must still be made available
in accordance with section (3) of the GNU General Public License.

This exception does not invalidate any other reasons why a work based
on this file might be covered by the GNU General Public License.
*/
/** @file
 * @brief macros to ease some common logging cases.
 *
 * The log macros are put into a file separate from the (base) logging files since
 * every coder can decide if he/she want's to use these macros or not.
 * (Not everyone like macros...)
 * 
 *
 * @author Reinhard Pfau
 *
 * @copyright &copy; Copyright 2008 by Intra2net AG
 *
 */

#ifndef __I2N_COMMON_LOG_MACROS_HPP__
#define __I2N_COMMON_LOG_MACROS_HPP__

#include "logfunc.hpp"


/*
**
*/

/**
 * @brief to be inserted in prepared but unimplemented functions.
 */
#define UNIMPLEMENTED() do{ ::I2n::Logger::GlobalLogger.warning(HERE) << "not implemented"; }while(false)


/**
 * @brief to be inserted in places which should be never reached during normal program execution.
 */
#define NOT_REACHED() do{ ::I2n::Logger::GlobalLogger.alert(HERE) << "this part should not be reached"; }while(false)




#endif
